@@ -1,3 +1,6 @@
+#ifndef TINC_EVENT_H
+#define TINC_EVENT_H
+
 /*
     event.h -- header for event.c
     Copyright (C) 2002-2009 Guus Sliepen <guus@tinc-vpn.org>,
@@ -18,9 +21,6 @@
     51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
-#ifndef __TINC_EVENT_H__
-#define __TINC_EVENT_H__
-
 #include "avl_tree.h"
 
 extern avl_tree_t *event_tree;
@@ -37,11 +37,11 @@ typedef struct event {
 extern void init_events(void);
 extern void exit_events(void);
 extern void expire_events(void);
-extern event_t *new_event(void) __attribute__ ((__malloc__));
-extern void free_event(event_t *);
-extern void event_add(event_t *);
-extern void event_del(event_t *);
+extern event_t *new_event(void) __attribute__((__malloc__));
+extern void free_event(event_t *event);
+extern void event_add(event_t *event);
+extern void event_del(event_t *event);
 extern event_t *get_expired_event(void);
 extern event_t *peek_next_event(void);
 
-#endif							/* __TINC_EVENT_H__ */
+#endif
