@@ -37,7 +37,7 @@ int device_fd = -1;
 static HANDLE device_handle = INVALID_HANDLE_VALUE;
 char *device = NULL;
 char *iface = NULL;
-static char *device_info = NULL;
+static const char *device_info = "Windows tap device";
 
 static uint64_t device_total_in = 0;
 static uint64_t device_total_out = 0;
@@ -66,17 +66,21 @@ static DWORD WINAPI tapreader(void *bla) {
 		if(!status) {
 			if(GetLastError() == ERROR_IO_PENDING) {
 				WaitForSingleObject(r_overlapped.hEvent, INFINITE);
-				if(!GetOverlappedResult(device_handle, &r_overlapped, &len, FALSE))
+
+				if(!GetOverlappedResult(device_handle, &r_overlapped, &len, FALSE)) {
 					continue;
+				}
 			} else {
 				logger(LOG_ERR, "Error while reading from %s %s: %s", device_info,
-					   device, strerror(errno));
+				       device, strerror(errno));
 				errors++;
+
 				if(errors >= 10) {
 					EnterCriticalSection(&mutex);
 					running = false;
 					LeaveCriticalSection(&mutex);
 				}
+
 				usleep(1000000);
 				continue;
 			}
@@ -113,8 +117,9 @@ static bool setup_device(void) {
 	get_config_string(lookup_config(config_tree, "Device"), &device);
 	get_config_string(lookup_config(config_tree, "Interface"), &iface);
 
-	if(device && iface)
+	if(device && iface) {
 		logger(LOG_WARNING, "Warning: both Device and Interface specified, results may not be as expected");
+	}
 
 	/* Open registry and look for network adapters */
 
@@ -123,44 +128,51 @@ static bool setup_device(void) {
 		return false;
 	}
 
-	for (i = 0; ; i++) {
+	for(i = 0; ; i++) {
 		len = sizeof(adapterid);
-		if(RegEnumKeyEx(key, i, adapterid, &len, 0, 0, 0, NULL))
+
+		if(RegEnumKeyEx(key, i, adapterid, &len, 0, 0, 0, NULL)) {
 			break;
+		}
 
 		/* Find out more about this adapter */
 
 		snprintf(regpath, sizeof(regpath), "%s\\%s\\Connection", NETWORK_CONNECTIONS_KEY, adapterid);
 
-                if(RegOpenKeyEx(HKEY_LOCAL_MACHINE, regpath, 0, KEY_READ, &key2))
+		if(RegOpenKeyEx(HKEY_LOCAL_MACHINE, regpath, 0, KEY_READ, &key2)) {
 			continue;
+		}
 
 		len = sizeof(adaptername);
 		err = RegQueryValueEx(key2, "Name", 0, 0, (LPBYTE)adaptername, &len);
 
 		RegCloseKey(key2);
 
-		if(err)
+		if(err) {
 			continue;
+		}
 
 		if(device) {
 			if(!strcmp(device, adapterid)) {
 				found = true;
 				break;
-			} else
+			} else {
 				continue;
+			}
 		}
 
 		if(iface) {
 			if(!strcmp(iface, adaptername)) {
 				found = true;
 				break;
-			} else
+			} else {
 				continue;
+			}
 		}
 
 		snprintf(tapname, sizeof(tapname), USERMODEDEVICEDIR "%s" TAPSUFFIX, adapterid);
 		device_handle = CreateFile(tapname, GENERIC_WRITE | GENERIC_READ, 0, 0, OPEN_EXISTING, FILE_ATTRIBUTE_SYSTEM | FILE_FLAG_OVERLAPPED, 0);
+
 		if(device_handle != INVALID_HANDLE_VALUE) {
 			found = true;
 			break;
@@ -174,11 +186,13 @@ static bool setup_device(void) {
 		return false;
 	}
 
-	if(!device)
+	if(!device) {
 		device = xstrdup(adapterid);
+	}
 
-	if(!iface)
+	if(!iface) {
 		iface = xstrdup(adaptername);
+	}
 
 	/* Try to open the corresponding tap device */
 
@@ -186,7 +200,7 @@ static bool setup_device(void) {
 		snprintf(tapname, sizeof(tapname), USERMODEDEVICEDIR "%s" TAPSUFFIX, device);
 		device_handle = CreateFile(tapname, GENERIC_WRITE | GENERIC_READ, 0, 0, OPEN_EXISTING, FILE_ATTRIBUTE_SYSTEM | FILE_FLAG_OVERLAPPED, 0);
 	}
-	
+
 	if(device_handle == INVALID_HANDLE_VALUE) {
 		logger(LOG_ERR, "%s (%s) is not a usable Windows tap device: %s", device, iface, winerror(GetLastError()));
 		return false;
@@ -222,8 +236,6 @@ static bool setup_device(void) {
 	status = true;
 	DeviceIoControl(device_handle, TAP_IOCTL_SET_MEDIA_STATUS, &status, sizeof(status), &status, sizeof(status), &len, NULL);
 
-	device_info = "Windows tap device";
-
 	logger(LOG_INFO, "%s (%s) is a %s", device, iface, device_info);
 
 	return true;
@@ -245,18 +257,20 @@ static bool write_packet(vpn_packet_t *packet) {
 	static vpn_packet_t queue;
 
 	ifdebug(TRAFFIC) logger(LOG_DEBUG, "Writing packet of %d bytes to %s",
-			   packet->len, device_info);
+	                        packet->len, device_info);
 
 	/* Check if there is something in progress */
 
 	if(queue.len) {
 		DWORD size;
 		BOOL success = GetOverlappedResult(device_handle, &w_overlapped, &size, FALSE);
+
 		if(success) {
 			ResetEvent(&w_overlapped);
 			queue.len = 0;
 		} else {
 			int err = GetLastError();
+
 			if(err != ERROR_IO_INCOMPLETE) {
 				ifdebug(TRAFFIC) logger(LOG_DEBUG, "Error completing previously queued write: %s", winerror(err));
 				ResetEvent(&w_overlapped);
@@ -275,10 +289,12 @@ static bool write_packet(vpn_packet_t *packet) {
 
 	if(!WriteFile(device_handle, queue.data, packet->len, &lenout, &w_overlapped)) {
 		int err = GetLastError();
+
 		if(err != ERROR_IO_PENDING) {
 			logger(LOG_ERR, "Error while writing to %s %s: %s", device_info, device, winerror(err));
 			return false;
 		}
+
 		// Write is being done asynchronously.
 		queue.len = packet->len;
 	} else {
