@@ -47,11 +47,6 @@ extern bool use_logfile;
 static sigset_t emptysigset;
 #endif
 
-static void memory_full(int size) {
-	logger(LOG_ERR, "Memory exhausted (couldn't allocate %d bytes), exitting.", size);
-	exit(1);
-}
-
 /* Some functions the less gifted operating systems might lack... */
 
 #ifdef HAVE_MINGW
@@ -71,42 +66,47 @@ bool install_service(void) {
 	SERVICE_DESCRIPTION description = {"Virtual Private Network daemon"};
 
 	manager = OpenSCManager(NULL, NULL, SC_MANAGER_ALL_ACCESS);
+
 	if(!manager) {
 		logger(LOG_ERR, "Could not open service manager: %s", winerror(GetLastError()));
 		return false;
 	}
 
 	if(!strchr(program_name, '\\')) {
-		GetCurrentDirectory(sizeof command - 1, command + 1);
-		strncat(command, "\\", sizeof command - strlen(command));
+		GetCurrentDirectory(sizeof(command) - 1, command + 1);
+		strncat(command, "\\", sizeof(command) - strlen(command));
 	}
 
-	strncat(command, program_name, sizeof command - strlen(command));
+	strncat(command, program_name, sizeof(command) - strlen(command));
 
-	strncat(command, "\"", sizeof command - strlen(command));
+	strncat(command, "\"", sizeof(command) - strlen(command));
 
 	for(argp = g_argv + 1; *argp; argp++) {
 		space = strchr(*argp, ' ');
-		strncat(command, " ", sizeof command - strlen(command));
-		
-		if(space)
-			strncat(command, "\"", sizeof command - strlen(command));
-		
-		strncat(command, *argp, sizeof command - strlen(command));
+		strncat(command, " ", sizeof(command) - strlen(command));
 
-		if(space)
-			strncat(command, "\"", sizeof command - strlen(command));
+		if(space) {
+			strncat(command, "\"", sizeof(command) - strlen(command));
+		}
+
+		strncat(command, *argp, sizeof(command) - strlen(command));
+
+		if(space) {
+			strncat(command, "\"", sizeof(command) - strlen(command));
+		}
 	}
 
 	service = CreateService(manager, identname, identname,
-			SERVICE_ALL_ACCESS, SERVICE_WIN32_OWN_PROCESS, SERVICE_AUTO_START, SERVICE_ERROR_NORMAL,
-			command, NULL, NULL, NULL, NULL, NULL);
-	
+	                        SERVICE_ALL_ACCESS, SERVICE_WIN32_OWN_PROCESS, SERVICE_AUTO_START, SERVICE_ERROR_NORMAL,
+	                        command, NULL, NULL, NULL, NULL, NULL);
+
 	if(!service) {
 		DWORD lasterror = GetLastError();
 		logger(LOG_ERR, "Could not create %s service: %s", identname, winerror(lasterror));
-		if(lasterror != ERROR_SERVICE_EXISTS)
+
+		if(lasterror != ERROR_SERVICE_EXISTS) {
 			return false;
+		}
 	}
 
 	if(service) {
@@ -116,16 +116,18 @@ bool install_service(void) {
 		service = OpenService(manager, identname, SERVICE_ALL_ACCESS);
 	}
 
-	if(!StartService(service, 0, NULL))
+	if(!StartService(service, 0, NULL)) {
 		logger(LOG_WARNING, "Could not start %s service: %s", identname, winerror(GetLastError()));
-	else
+	} else {
 		logger(LOG_INFO, "%s service started", identname);
+	}
 
 	return true;
 }
 
 bool remove_service(void) {
 	manager = OpenSCManager(NULL, NULL, SC_MANAGER_ALL_ACCESS);
+
 	if(!manager) {
 		logger(LOG_ERR, "Could not open service manager: %s", winerror(GetLastError()));
 		return false;
@@ -138,10 +140,11 @@ bool remove_service(void) {
 		return false;
 	}
 
-	if(!ControlService(service, SERVICE_CONTROL_STOP, &status))
+	if(!ControlService(service, SERVICE_CONTROL_STOP, &status)) {
 		logger(LOG_ERR, "Could not stop %s service: %s", identname, winerror(GetLastError()));
-	else
+	} else {
 		logger(LOG_INFO, "%s service stopped", identname);
+	}
 
 	if(!DeleteService(service)) {
 		logger(LOG_ERR, "Could not remove %s service: %s", identname, winerror(GetLastError()));
@@ -155,61 +158,64 @@ bool remove_service(void) {
 
 DWORD WINAPI controlhandler(DWORD request, DWORD type, LPVOID boe, LPVOID bah) {
 	switch(request) {
-		case SERVICE_CONTROL_INTERROGATE:
-			SetServiceStatus(statushandle, &status);
-			return NO_ERROR;
-		case SERVICE_CONTROL_STOP:
-			logger(LOG_NOTICE, "Got %s request", "SERVICE_CONTROL_STOP");
-			break;
-		case SERVICE_CONTROL_SHUTDOWN:
-			logger(LOG_NOTICE, "Got %s request", "SERVICE_CONTROL_SHUTDOWN");
-			break;
-		default:
-			logger(LOG_WARNING, "Got unexpected request %d", (int)request);
-			return ERROR_CALL_NOT_IMPLEMENTED;
+	case SERVICE_CONTROL_INTERROGATE:
+		SetServiceStatus(statushandle, &status);
+		return NO_ERROR;
+
+	case SERVICE_CONTROL_STOP:
+		logger(LOG_NOTICE, "Got %s request", "SERVICE_CONTROL_STOP");
+		break;
+
+	case SERVICE_CONTROL_SHUTDOWN:
+		logger(LOG_NOTICE, "Got %s request", "SERVICE_CONTROL_SHUTDOWN");
+		break;
+
+	default:
+		logger(LOG_WARNING, "Got unexpected request %d", (int)request);
+		return ERROR_CALL_NOT_IMPLEMENTED;
 	}
 
 	if(running) {
 		running = false;
-		status.dwWaitHint = 30000; 
-		status.dwCurrentState = SERVICE_STOP_PENDING; 
+		status.dwWaitHint = 30000;
+		status.dwCurrentState = SERVICE_STOP_PENDING;
 		SetServiceStatus(statushandle, &status);
 		return NO_ERROR;
 	} else {
-		status.dwWaitHint = 0; 
-		status.dwCurrentState = SERVICE_STOPPED; 
+		status.dwWaitHint = 0;
+		status.dwCurrentState = SERVICE_STOPPED;
 		SetServiceStatus(statushandle, &status);
 		exit(1);
 	}
 
 }
 
-VOID WINAPI run_service(DWORD argc, LPTSTR* argv) {
+VOID WINAPI run_service(DWORD argc, LPTSTR *argv) {
 	extern int main2(int argc, char **argv);
 
-	status.dwServiceType = SERVICE_WIN32; 
+	status.dwServiceType = SERVICE_WIN32;
 	status.dwControlsAccepted = SERVICE_ACCEPT_STOP | SERVICE_ACCEPT_SHUTDOWN;
-	status.dwWin32ExitCode = 0; 
-	status.dwServiceSpecificExitCode = 0; 
-	status.dwCheckPoint = 0; 
+	status.dwWin32ExitCode = 0;
+	status.dwServiceSpecificExitCode = 0;
+	status.dwCheckPoint = 0;
 
-	statushandle = RegisterServiceCtrlHandlerEx(identname, controlhandler, NULL); 
+	statushandle = RegisterServiceCtrlHandlerEx(identname, controlhandler, NULL);
 
-	if (!statushandle) {
+	if(!statushandle) {
 		logger(LOG_ERR, "System call `%s' failed: %s", "RegisterServiceCtrlHandlerEx", winerror(GetLastError()));
 	} else {
-		status.dwWaitHint = 30000; 
-		status.dwCurrentState = SERVICE_START_PENDING; 
+		status.dwWaitHint = 30000;
+		status.dwCurrentState = SERVICE_START_PENDING;
 		SetServiceStatus(statushandle, &status);
 
-		status.dwWaitHint = 0; 
+		status.dwWaitHint = 0;
 		status.dwCurrentState = SERVICE_RUNNING;
 		SetServiceStatus(statushandle, &status);
 
 		main2(argc, argv);
 
 		status.dwWaitHint = 0;
-		status.dwCurrentState = SERVICE_STOPPED; 
+		status.dwCurrentState = SERVICE_STOPPED;
 		SetServiceStatus(statushandle, &status);
 	}
 
@@ -225,9 +231,9 @@ bool init_service(void) {
 	if(!StartServiceCtrlDispatcher(services)) {
 		if(GetLastError() == ERROR_FAILED_SERVICE_CONTROLLER_CONNECT) {
 			return false;
-		}
-		else
+		} else {
 			logger(LOG_ERR, "System call `%s' failed: %s", "StartServiceCtrlDispatcher", winerror(GetLastError()));
+		}
 	}
 
 	return true;
@@ -246,9 +252,11 @@ static bool write_pidfile(void) {
 	if(pid) {
 		if(netname)
 			fprintf(stderr, "A tincd is already running for net `%s' with pid %ld.\n",
-					netname, (long)pid);
-		else
+			        netname, (long)pid);
+		else {
 			fprintf(stderr, "A tincd is already running with pid %ld.\n", (long)pid);
+		}
+
 		return false;
 	}
 
@@ -274,21 +282,24 @@ bool kill_other(int signal) {
 	if(!pid) {
 		if(netname)
 			fprintf(stderr, "No other tincd is running for net `%s'.\n",
-					netname);
-		else
+			        netname);
+		else {
 			fprintf(stderr, "No other tincd is running.\n");
+		}
+
 		return false;
 	}
 
-	errno = 0;					/* No error, sometimes errno is only changed on error */
+	errno = 0;                                      /* No error, sometimes errno is only changed on error */
 
 	/* ESRCH is returned when no process with that pid is found */
 	if(kill(pid, signal) && errno == ESRCH) {
 		if(netname)
 			fprintf(stderr, "The tincd for net `%s' is no longer running. ",
-					netname);
-		else
+			        netname);
+		else {
 			fprintf(stderr, "The tincd is no longer running. ");
+		}
 
 		fprintf(stderr, "Removing stale lock file.\n");
 		remove_pid(pidfilename);
@@ -309,8 +320,10 @@ bool detach(void) {
 	/* First check if we can open a fresh new pidfile */
 
 #ifndef HAVE_MINGW
-	if(!write_pidfile())
+
+	if(!write_pidfile()) {
 		return false;
+	}
 
 	/* If we succeeded in doing that, detach */
 
@@ -319,9 +332,10 @@ bool detach(void) {
 
 	if(do_detach) {
 #ifndef HAVE_MINGW
+
 		if(daemon(0, 0)) {
 			fprintf(stderr, "Couldn't detach from terminal: %s",
-					strerror(errno));
+			        strerror(errno));
 			return false;
 		}
 
@@ -331,18 +345,20 @@ bool detach(void) {
 			fprintf(stderr, "Could not write pid file %s: %s\n", pidfilename, strerror(errno));
 			return false;
 		}
+
 #else
-		if(!statushandle)
+
+		if(!statushandle) {
 			exit(install_service());
+		}
+
 #endif
 	}
 
-	openlogger(identname, use_logfile?LOGMODE_FILE:(do_detach?LOGMODE_SYSLOG:LOGMODE_STDERR));
+	openlogger(identname, use_logfile ? LOGMODE_FILE : (do_detach ? LOGMODE_SYSLOG : LOGMODE_STDERR));
 
 	logger(LOG_NOTICE, "tincd %s starting, debug level %d",
-			   VERSION, debug_level);
-
-	xalloc_fail_func = memory_full;
+	       VERSION, debug_level);
 
 	return true;
 }
@@ -350,8 +366,11 @@ bool detach(void) {
 #ifdef HAVE_PUTENV
 void unputenv(char *p) {
 	char *e = strchr(p, '=');
-	if(!e)
+
+	if(!e) {
 		return;
+	}
+
 	int len = e - p;
 #ifndef HAVE_UNSETENV
 #ifdef HAVE_MINGW
@@ -368,13 +387,16 @@ void unputenv(char *p) {
 	// We must keep what we putenv() around in memory.
 	// To do this without memory leaks, keep things in a list and reuse if possible.
 	static list_t list = {};
+
 	for(list_node_t *node = list.head; node; node = node->next) {
 		char *data = node->data;
+
 		if(!strcmp(data, var)) {
 			putenv(data);
 			return;
 		}
 	}
+
 	char *data = xstrdup(var);
 	list_insert_tail(&list, data);
 	putenv(data);
@@ -396,13 +418,18 @@ bool execute_script(const char *name, char **envp) {
 #ifndef HAVE_MINGW
 	len = xasprintf(&scriptname, "\"%s/%s\"", confbase, name);
 #else
-	if(cfg_interpreter)
+
+	if(cfg_interpreter) {
 		len = xasprintf(&scriptname, "\"%s/%s\"", confbase, name);
-	else
+	} else {
 		len = xasprintf(&scriptname, "\"%s/%s.bat\"", confbase, name);
+	}
+
 #endif
-	if(len < 0)
+
+	if(len < 0) {
 		return false;
+	}
 
 	scriptname[len - 1] = '\0';
 
@@ -418,16 +445,19 @@ bool execute_script(const char *name, char **envp) {
 		free(scriptname);
 		len = xasprintf(&scriptname, "%s \"%s/%s\"", interpreter, confbase, name);
 		free(interpreter);
-		if(len < 0)
+
+		if(len < 0) {
 			return false;
+		}
 	}
 
 	ifdebug(STATUS) logger(LOG_INFO, "Executing script %s", name);
 
 	/* Set environment */
-	
-	for(i = 0; envp[i]; i++)
+
+	for(i = 0; envp[i]; i++) {
 		putenv(envp[i]);
+	}
 
 	scriptname[len - 1] = '\"';
 	status = system(scriptname);
@@ -436,30 +466,34 @@ bool execute_script(const char *name, char **envp) {
 
 	/* Unset environment */
 
-	for(i = 0; envp[i]; i++)
+	for(i = 0; envp[i]; i++) {
 		unputenv(envp[i]);
+	}
 
 	if(status != -1) {
 #ifdef WEXITSTATUS
-		if(WIFEXITED(status)) {	/* Child exited by itself */
+
+		if(WIFEXITED(status)) { /* Child exited by itself */
 			if(WEXITSTATUS(status)) {
 				logger(LOG_ERR, "Script %s exited with non-zero status %d",
-					   name, WEXITSTATUS(status));
+				       name, WEXITSTATUS(status));
 				return false;
 			}
-		} else if(WIFSIGNALED(status)) {	/* Child was killed by a signal */
+		} else if(WIFSIGNALED(status)) {        /* Child was killed by a signal */
 			logger(LOG_ERR, "Script %s was killed by signal %d (%s)",
-				   name, WTERMSIG(status), strsignal(WTERMSIG(status)));
+			       name, WTERMSIG(status), strsignal(WTERMSIG(status)));
 			return false;
-		} else {			/* Something strange happened */
+		} else {                        /* Something strange happened */
 			logger(LOG_ERR, "Script %s terminated abnormally", name);
 			return false;
 		}
+
 #endif
 	} else {
 		logger(LOG_ERR, "System call `%s' failed: %s", "system", strerror(errno));
 		return false;
 	}
+
 #endif
 	return true;
 }
@@ -471,24 +505,30 @@ bool execute_script(const char *name, char **envp) {
 
 #ifndef HAVE_MINGW
 static RETSIGTYPE sigterm_handler(int a) {
+	(void)a;
 	logger(LOG_NOTICE, "Got %s signal", "TERM");
-	if(running)
+
+	if(running) {
 		running = false;
-	else
+	} else {
 		exit(1);
+	}
 }
 
 static RETSIGTYPE sigquit_handler(int a) {
+	(void)a;
 	logger(LOG_NOTICE, "Got %s signal", "QUIT");
-	if(running)
+
+	if(running) {
 		running = false;
-	else
+	} else {
 		exit(1);
+	}
 }
 
 static RETSIGTYPE fatal_signal_square(int a) {
 	logger(LOG_ERR, "Got another fatal signal %d (%s): not restarting.", a,
-		   strsignal(a));
+	       strsignal(a));
 	exit(1);
 }
 
@@ -515,39 +555,44 @@ static RETSIGTYPE fatal_signal_handler(int a) {
 }
 
 static RETSIGTYPE sighup_handler(int a) {
+	(void)a;
 	logger(LOG_NOTICE, "Got %s signal", "HUP");
 	sighup = true;
 }
 
 static RETSIGTYPE sigint_handler(int a) {
+	(void)a;
 	static int saved_debug_level = -1;
 
 	logger(LOG_NOTICE, "Got %s signal", "INT");
 
 	if(saved_debug_level != -1) {
 		logger(LOG_NOTICE, "Reverting to old debug level (%d)",
-			saved_debug_level);
+		       saved_debug_level);
 		debug_level = saved_debug_level;
 		saved_debug_level = -1;
 	} else {
 		logger(LOG_NOTICE,
-			"Temporarily setting debug level to 5.  Kill me with SIGINT again to go back to level %d.",
-			debug_level);
+		       "Temporarily setting debug level to 5.  Kill me with SIGINT again to go back to level %d.",
+		       debug_level);
 		saved_debug_level = debug_level;
 		debug_level = 5;
 	}
 }
 
 static RETSIGTYPE sigalrm_handler(int a) {
+	(void)a;
 	logger(LOG_NOTICE, "Got %s signal", "ALRM");
 	sigalrm = true;
 }
 
 static RETSIGTYPE sigusr1_handler(int a) {
+	(void)a;
 	dump_connections();
 }
 
 static RETSIGTYPE sigusr2_handler(int a) {
+	(void)a;
 	devops.dump_stats();
 	dump_nodes();
 	dump_edges();
@@ -555,14 +600,17 @@ static RETSIGTYPE sigusr2_handler(int a) {
 }
 
 static RETSIGTYPE sigwinch_handler(int a) {
+	(void)a;
 	do_purge = true;
 }
 
 static RETSIGTYPE unexpected_signal_handler(int a) {
+	(void)a;
 	logger(LOG_WARNING, "Got unexpected signal %d (%s)", a, strsignal(a));
 }
 
 static RETSIGTYPE ignore_signal_handler(int a) {
+	(void)a;
 	ifdebug(SCARY_THINGS) logger(LOG_DEBUG, "Ignored signal %d (%s)", a, strsignal(a));
 }
 
@@ -601,25 +649,30 @@ void setup_signals(void) {
 	/* Set a default signal handler for every signal, errors will be
 	   ignored. */
 	for(i = 1; i < NSIG; i++) {
-		if(!do_detach)
+		if(!do_detach) {
 			act.sa_handler = SIG_DFL;
-		else
+		} else {
 			act.sa_handler = unexpected_signal_handler;
+		}
+
 		sigaction(i, &act, NULL);
 	}
 
 	/* If we didn't detach, allow coredumps */
-	if(!do_detach)
+	if(!do_detach) {
 		sighandlers[3].handler = SIG_DFL;
+	}
 
 	/* Then, for each known signal that we want to catch, assign a
 	   handler to the signal, with error checking this time. */
 	for(i = 0; sighandlers[i].signal; i++) {
 		act.sa_handler = sighandlers[i].handler;
+
 		if(sigaction(sighandlers[i].signal, &act, NULL) < 0)
 			fprintf(stderr, "Installing signal handler for signal %d (%s) failed: %s\n",
-					sighandlers[i].signal, strsignal(sighandlers[i].signal),
-					strerror(errno));
+			        sighandlers[i].signal, strsignal(sighandlers[i].signal),
+			        strerror(errno));
 	}
+
 #endif
 }
