@@ -1,7 +1,10 @@
+#ifndef TINC_ROUTE_H
+#define TINC_ROUTE_H
+
 /*
     route.h -- header file for route.c
     Copyright (C) 2000-2005 Ivo Timmermans
-                  2000-2012 Guus Sliepen <guus@tinc-vpn.org>         
+                  2000-2012 Guus Sliepen <guus@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,9 +21,6 @@
     51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
-#ifndef __TINC_ROUTE_H__
-#define __TINC_ROUTE_H__
-
 #include "net.h"
 #include "node.h"
 
@@ -54,6 +54,6 @@ extern int macexpire;
 extern mac_t mymac;
 
 extern void age_subnets(void);
-extern void route(struct node_t *, struct vpn_packet_t *);
+extern void route(struct node_t *source, struct vpn_packet_t *packet);
 
-#endif							/* __TINC_ROUTE_H__ */
+#endif
