@@ -1,3 +1,6 @@
+#ifndef TINC_SYSTEM_H
+#define TINC_SYSTEM_H
+
 /*
     system.h -- system headers
     Copyright (C) 1998-2005 Ivo Timmermans
@@ -18,19 +21,10 @@
     51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
-#ifndef __TINC_SYSTEM_H__
-#define __TINC_SYSTEM_H__
-
-#include "../config.h"
+#include "config.h"
 
 #include "have.h"
 
-#ifndef HAVE_STDBOOL_H
-typedef int bool;
-#define true 1
-#define false 0
-#endif
-
 #ifndef HAVE_STRSIGNAL
 # define strsignal(p) ""
 #endif
@@ -43,4 +37,4 @@ typedef int bool;
 typedef int socklen_t;
 #endif
 
-#endif /* __TINC_SYSTEM_H__ */
+#endif
